@@ -42,10 +42,11 @@ class TestRemoteAction(unittest.TestCase):
         cls._mock_ckan = _mock_ckan
         while True: # wait for the server to start
             try:
-                urlopen('http://localhost:8901')
-            except URLError as e:
-                if hasattr(e, 'getcode') and e.getcode() == 404:
+                r = urlopen('http://localhost:8901/api/action/site_read')
+                if r.getcode() == 200:
                     break
+            except URLError as e:
+                pass
             time.sleep(0.1)
 
     def setUp(self):
@@ -67,11 +68,15 @@ class TestRemoteAction(unittest.TestCase):
             self.ckan.action.test_echo_user_agent().startswith('ckanapi'))
 
     def test_custom_ua(self):
-        ua = 'testckanapibot/1.0 (+https://github.com/open-data/ckanapi)'
+        ua = 'testckanapibot/1.0 (+https://github.com/ckan/ckanapi)'
         ckan = ckanapi.RemoteCKAN('http://localhost:8901', user_agent=ua)
 
         self.assertEqual(ckan.action.test_echo_user_agent(), ua)
 
+    def test_default_content_type(self):
+        self.assertEqual(self.ckan.action.test_echo_content_type(),
+            "application/json")
+
     def test_resource_upload(self):
         res = self.ckan.call_action('test_upload',
             {'option': "42"},
@@ -84,6 +89,12 @@ class TestRemoteAction(unittest.TestCase):
             files={'upload': StringIO(NUMBER_THING_CSV)})
         self.assertEqual(res.get('option'), "42")
 
+    def test_resource_upload_content_type(self):
+        res = self.ckan.call_action('test_echo_content_type',
+            {'option': "42"},
+            files={'upload': StringIO(NUMBER_THING_CSV)})
+        self.assertEqual(res.split(';')[0], "multipart/form-data")
+
     @classmethod
     def tearDownClass(cls):
         cls._mock_ckan.kill()
